2024-05-17 Version: 1.0.1
- Update API CancelJobRun: update param workspaceId.
- Update API CancelJobRun: update param jobRunId.
- Update API GetJobRun: update param workspaceId.
- Update API GetJobRun: update param jobRunId.
- Update API ListJobRuns: update param workspaceId.
- Update API StartJobRun: update param workspaceId.


2024-04-16 Version: 1.0.0
- Generated python 2023-08-08 for emr-serverless-spark.

